@@ -76,11 +76,9 @@ capture_first_df <- structure(function # Capture first match in columns of a dat
   }
   out
 ### data.table with same number of rows as subject, with an additional
-### column for each named capture group specified in ...  
+### column for each named capture group specified in ...
 }, ex=function(){
 
-  library(nc)
-
   ## The JobID column can be match with a complicated regular
   ## expression, that we will build up from small sub-pattern list
   ## variables that are easy to understand independently.
@@ -98,7 +96,7 @@ capture_first_df <- structure(function # Capture first match in columns of a dat
   end.pattern <- list(
     "-",
     task.end=int.pattern)
-  capture_first_df(sacct.df, JobID=list(
+  nc::capture_first_df(sacct.df, JobID=list(
     end.pattern, nomatch.error=FALSE))
 
   ## Match the whole range inside square brackets.
@@ -107,7 +105,7 @@ capture_first_df <- structure(function # Capture first match in columns of a dat
     task.start=int.pattern,
     end.pattern, "?", #end is optional.
     "[]]")
-  capture_first_df(sacct.df, JobID=list(
+  nc::capture_first_df(sacct.df, JobID=list(
     range.pattern, nomatch.error=FALSE))
 
   ## Match either a single task ID or a range, after an underscore.
@@ -117,23 +115,23 @@ capture_first_df <- structure(function # Capture first match in columns of a dat
       task.id=int.pattern,
       "|",#either one task(above) or range(below)
       range.pattern))
-  capture_first_df(sacct.df, JobID=task.pattern)
+  nc::capture_first_df(sacct.df, JobID=task.pattern)
 
   ## Match type suffix alone.
   type.pattern <- list(
     "[.]",
     type=".*")
-  capture_first_df(sacct.df, JobID=list(
+  nc::capture_first_df(sacct.df, JobID=list(
     type.pattern, nomatch.error=FALSE))
 
   ## Match task and optional type suffix.
   task.type.pattern <- list(
     task.pattern,
     type.pattern, "?")
-  capture_first_df(sacct.df, JobID=task.type.pattern)
+  nc::capture_first_df(sacct.df, JobID=task.type.pattern)
 
   ## Match full JobID and Elapsed columns.
-  (task.df <- capture_first_df(
+  (task.df <- nc::capture_first_df(
     sacct.df,
     JobID=list(
       job=int.pattern,
