@@ -1,12 +1,13 @@
 capture_first_vec <- structure(function # Capture first match in each character vector element
-### Extract the first match of a regex pattern from each
-### of several subject strings. This function uses var_args_list
-### to analyze the arguments.
-### For the first match in every row of a data.frame, using
-### a different regex for each column, use capture_first_df. For all
-### matches in one multi-line text file use capture_all_str.
-### To avoid repetition when a group name is also used in the pattern,
-### use field.
+### Extract the first match of a regex pattern from each of several
+### subject strings. This function uses var_args_list to analyze the
+### arguments. For all matches in one multi-line text file use
+### capture_all_str. For the first match in every row of a data.frame,
+### using a different regex for each column, use capture_first_df. For
+### matching column names in a wide data.frame and then melting those
+### columns, see capture_melt_single and
+### capture_melt_multiple. To avoid repetition when a group name
+### is also used in the pattern, use field.
 (subject.vec,
 ### The subject character vector.
   ...,
@@ -34,11 +35,14 @@ capture_first_vec <- structure(function # Capture first match in each character
   stop_for_na <- function(no.match){
     if(isTRUE(nomatch.error) && any(no.match)){
       i <- which(no.match)
-      stop("subject",
-           ifelse(length(i)==1, "", "s"),
-           " ",
-           paste(i, collapse=","),
-           " did not match regex below\n", L$pattern)
+      stop(
+        "subject",
+        ifelse(length(i)==1, "", "s"),
+        " ",
+        paste(i, collapse=","),
+        " did not match regex below; ",
+        "to output missing rows use nomatch.error=FALSE\n",
+        L$pattern)
     }
   }
   m <- if(engine=="PCRE"){
@@ -66,64 +70,51 @@ capture_first_vec <- structure(function # Capture first match in each character
   }
   apply_type_funs(m, L$fun.list)
 ### data.table with one row for each subject, and one column for each
-### capture group. 
+### capture group.
 }, ex=function(){
-  
-  library(nc)
-  
-  named.subject.vec <- c(
-    ten="chr10:213,054,000-213,055,000",
-    M="chrM:111,000",
-    one="chr1:110-111 chr2:220-222") # two possible matches.
+
+  chr.pos.vec <- c(
+    "chr10:213,054,000-213,055,000",
+    "chrM:111,000",
+    "chr1:110-111 chr2:220-222") # two possible matches.
   ## Find the first match in each element of the subject character
   ## vector. Named argument values are used to create capture groups
   ## in the generated regex, and argument names become column names in
-  ## the result. 
-  (dt.chr.cols <- capture_first_vec(
-    named.subject.vec,
+  ## the result.
+  (dt.chr.cols <- nc::capture_first_vec(
+    chr.pos.vec,
     chrom="chr.*?",
     ":",
     chromStart="[0-9,]+"))
-  
+
   ## Even when no type conversion functions are specified, the result
   ## is always a data.table:
   str(dt.chr.cols)
-  
+
   ## Conversion functions are used to convert the previously named
   ## group, and patterns may be saved in lists for re-use.
   keep.digits <- function(x)as.integer(gsub("[^0-9]", "", x))
   int.pattern <- list("[0-9,]+", keep.digits)
   range.pattern <- list(
-    chrom="chr.*?", 
+    chrom="chr.*?",
     ":",
     chromStart=int.pattern,
     list( # un-named list becomes non-capturing group.
       "-",
       chromEnd=int.pattern
     ), "?") # chromEnd is optional.
-  (dt.int.cols <- capture_first_vec(
-    named.subject.vec, range.pattern))
-  
+  (dt.int.cols <- nc::capture_first_vec(
+    chr.pos.vec, range.pattern))
+
   ## Conversion functions used to create non-char columns.
   str(dt.int.cols)
-  
+
   ## NA used to indicate no match or missing subject.
   na.vec <- c(
-    nomatch="this will not match",
-    missing=NA, # neither will this.
-    named.subject.vec)
-  capture_first_vec(na.vec, range.pattern, nomatch.error=FALSE)
-  
-  ## alternate regex engine, but this example with emoji only works
-  ## with recent versions of ICU.
-  if(requireNamespace("stringi") && stringi::stri_info()$ICU.version >= 59){
-    capture_first_vec(
-      "foo a\U0001F60E# bar",
-      before=".*?",
-      emoji="\\p{EMOJI_Presentation}",
-      after=".*",
-      engine="ICU")
-  }
-  
+    "this will not match",
+    NA, # neither will this.
+    chr.pos.vec)
+  nc::capture_first_vec(na.vec, range.pattern, nomatch.error=FALSE)
+
 })
 
